@@ -29,13 +29,14 @@
 /* ----------------------------------
  * version info
  * ---------------------------------- */
-static const char man_version[] = "10.8";
+static const char man_version[] = "10.9";
 static const char man_date[] = "June 2012";
 
 /* ----------------------------------
  * definitions
  * ---------------------------------- */
 #define MAX_LINE 32768
+#define QS_HUGE_STR 2048
 #define CR 13
 #define LF 10
 
@@ -78,4 +79,7 @@ long qs_countEvent(qs_event_t **l_qs_event);
 void qs_deleteEvent(qs_event_t **l_qs_event, char *id);
 void qs_GCEvent(qs_event_t **l_qs_event);
 
+/* log */
+void qs_deleteOldFiles(const char *file_name, int generations);
+
 #endif
