@@ -28,7 +28,7 @@
  *
  */
 
-static const char revision[] = "$Id: qslog.c,v 1.46 2012/05/15 18:51:27 pbuchbinder Exp $";
+static const char revision[] = "$Id: qslog.c,v 1.49 2012/06/26 19:58:16 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <string.h>
@@ -59,6 +59,7 @@ static const char revision[] = "$Id: qslog.c,v 1.46 2012/05/15 18:51:27 pbuchbin
 #define LOG_DET ".detailed"
 #define RULE_DELIM ':'
 #define MAX_CLIENT_ENTRIES 25000
+#define QS_GENERATIONS 14
 
 /* ----------------------------------
  * structures
@@ -103,6 +104,10 @@ typedef struct stat_rec_st {
   long duration_6;
   long connections;
 
+  unsigned long long sum;
+  unsigned long long average;
+  unsigned long long averAge;
+
   long status_1;
   long status_2;
   long status_3;
@@ -133,6 +138,7 @@ static FILE *m_f2 = NULL;
 static char  m_file_name[MAX_LINE];
 static char  m_file_name2[MAX_LINE];
 static int   m_rotate = 0;
+static int   m_generations = QS_GENERATIONS;
 /* regex to search the time string */
 static regex_t m_trx;
 static regex_t m_trx2;
@@ -142,6 +148,7 @@ static int   m_offline_data = 0;
 static char  m_date_str[MAX_LINE];
 static int   m_mem = 0;
 static int   m_avms = 0;
+static int   m_customcounter = 0;
 static apr_table_t *m_client_entries = NULL;
 static int   m_max_client_entries = 0;
 static int   m_offline_count = 0;
@@ -209,6 +216,21 @@ static char *skipElement(const char* line) {
   return p;
 }
 
+/**
+ * Cut fp
+ */
+static void qsNoFloat(char *s) {
+  char *pn = strchr(s, '.');
+  if(pn) {
+    pn[0] = '\0';
+  } else {
+    pn = strchr(s, ',');
+    if(pn) {
+      pn[0] = '\0';
+    }
+  }
+}
+
 /**
  * Strip a number.
  */
@@ -360,9 +382,12 @@ static void printStat2File(FILE *f, char *timeStr, stat_rec_t *stat_rec,
   char ip[256];
   char usr[256];
   char avms[256];
+  char custom[256];
   bis[0] = '\0';
   esco[0] = '\0';
   avms[0] = '\0';
+  custom[0] = '\0';
+
   if(stat_rec->i_byte_count != -1) {
     sprintf(bis, NBIS";%lld;", stat_rec->i_byte_count/LOG_INTERVAL);
   }
@@ -375,6 +400,13 @@ static void printStat2File(FILE *f, char *timeStr, stat_rec_t *stat_rec,
     // improve accuracy (rounding errors):
     stat_rec->duration_count = stat_rec->duration_count_ms / 1000;
   }
+  if(m_customcounter) {
+    // max len: 18446744073709551615
+    sprintf(custom, "s;%llu;a;%llu;A;%llu;",
+            stat_rec->sum,
+            stat_rec->average / (stat_rec->line_count == 0 ? 1 : stat_rec->line_count),
+            stat_rec->averAge / (stat_rec->line_count == 0 ? 1 : stat_rec->line_count));
+  }
   if(main) {
     sprintf(ip, "ip;%ld;", qs_countEvent(&m_ip_list));
     sprintf(usr, "usr;%ld;", qs_countEvent(&m_user_list));
@@ -413,6 +445,7 @@ static void printStat2File(FILE *f, char *timeStr, stat_rec_t *stat_rec,
           "qT;%ld;"
           "qL;%ld;"
           "qs;%ld;"
+          "%s"
           ,
           timeStr,
           main ? "" : stat_rec->id,
@@ -443,7 +476,8 @@ static void printStat2File(FILE *f, char *timeStr, stat_rec_t *stat_rec,
           stat_rec->qos_k,
           stat_rec->qos_t,
           stat_rec->qos_l,
-          stat_rec->qos_ser
+          stat_rec->qos_ser,
+          custom
           );
   stat_rec->line_count = 0;
   stat_rec->byte_count = 0;
@@ -453,6 +487,9 @@ static void printStat2File(FILE *f, char *timeStr, stat_rec_t *stat_rec,
   if(main && (stat_rec->connections != -1)) {
     stat_rec->connections = 0;
   }
+  stat_rec->sum = 0;
+  stat_rec->average = 0;
+  stat_rec->averAge = 0;
   stat_rec->status_1 = 0;
   stat_rec->status_2 = 0;
   stat_rec->status_3 = 0;
@@ -518,6 +555,10 @@ static stat_rec_t *createRec(const char *id, const char *pattern) {
   rec->duration_6 = 0;
   rec->connections = -1;
 
+  rec->sum = 0;
+  rec->average = 0;
+  rec->averAge = 0;
+
   rec->status_1 = 0;
   rec->status_2 = 0;
   rec->status_3 = 0;
@@ -680,6 +721,7 @@ static void updateClient(stat_rec_t *rec, char *T, char *t, char *D, char *S,
  * Updates standard record
  */
 static void updateRec(stat_rec_t *rec, char *T, char *t, char *D, char *S,
+                      char *s, char *a, char *A,
                       char *BI, char *B, char *R, char *I, char *U, char *Q,
                       char *k, char *C, long tme, long tmems) {
   if(Q != NULL) {
@@ -726,6 +768,15 @@ static void updateRec(stat_rec_t *rec, char *T, char *t, char *D, char *S,
       rec->connections++;
     }
   }
+  if(s != NULL) {
+    rec->sum += atol(s);
+  }
+  if(a != NULL) {
+    rec->average += atol(a);
+  }
+  if(A != NULL) {
+    rec->averAge += atol(A);
+  }
   if(S != NULL) {
     if(S[0] == '1') {
       rec->status_1++;
@@ -791,6 +842,9 @@ static void updateStat(const char *cstr, char *line) {
   char *Q = NULL; /* mod_qos event message */
   char *k = NULL; /* connections (keep alive requests = 0) */
   char *C = NULL; /* custom patter matching the config file */
+  char *s = NULL; /* sum */
+  char *a = NULL; /* avarage 1 */
+  char *A = NULL; /* average 2 */
   const char *c = cstr;
   char *l = line;
   long tme;
@@ -850,6 +904,18 @@ static void updateStat(const char *cstr, char *line) {
       if(l != NULL && l[0] != '\0') {
         Q = cutNext(&l);
       }
+    } else if(c[0] == 's') {
+      if(l != NULL && l[0] != '\0') {
+        s = cutNext(&l);
+      }
+    } else if(c[0] == 'a') {
+      if(l != NULL && l[0] != '\0') {
+        a = cutNext(&l);
+      }
+    } else if(c[0] == 'A') {
+      if(l != NULL && l[0] != '\0') {
+        A = cutNext(&l);
+      }
     } else if(c[0] == ' ') {
       /* do nothing */
     } else {
@@ -879,6 +945,18 @@ static void updateStat(const char *cstr, char *line) {
   if(S != NULL) {
     stripNum(&S);
   }
+  if(s != NULL) {
+    stripNum(&s);
+    qsNoFloat(s);
+  }
+  if(a != NULL) {
+    stripNum(&a);
+    qsNoFloat(a);
+  }
+  if(A != NULL) {
+    stripNum(&A);
+    qsNoFloat(A);
+  }
   tme = 0;
   if(T != NULL || t != NULL || D != NULL) {
     /* response duration */
@@ -896,9 +974,9 @@ static void updateStat(const char *cstr, char *line) {
       tme = tmems / 1000;
     }
   }
-  updateRec(m_stat_rec, T, t, D, S, BI, B, R, I, U, Q, k, C, tme, tmems);
+  updateRec(m_stat_rec, T, t, D, S, s, a, A, BI, B, R, I, U, Q, k, C, tme, tmems);
   if(rec) {
-    updateRec(rec, T, t, D, S, BI, B, R, I, U, Q, k, C, tme, tmems);
+    updateRec(rec, T, t, D, S, s, a, A, BI, B, R, I, U, Q, k, C, tme, tmems);
   }
   if(m_offline_count) {
     updateClient(NULL, T, t, D, S, BI, B, R, I, U, Q, k, C, tme);
@@ -1131,10 +1209,12 @@ static void *loggerThread(void *argv) {
         if(rename(m_file_name, arch) != 0) {
           qerror("failed to move file '%s': %s", arch, strerror(errno));
         }
+        qs_deleteOldFiles(m_file_name, m_generations);
         m_f = fopen(m_file_name, "a+");
         if(m_f2) {
           fclose(m_f2);
           rename(m_file_name2, arch2);
+          qs_deleteOldFiles(m_file_name2, m_generations);
           m_f2 = fopen(m_file_name2, "a+");
         }
       }
@@ -1161,7 +1241,7 @@ static void usage(const char *cmd, int man) {
   if(man) {
     printf(".SH SYNOPSIS\n");
   }
-  qs_man_print(man, "%s%s -f <format_string> -o <out_file> [-p [-v]] [-x] [-u <name>] [-m] [-c <path>]\n", man ? "" : "Usage: ", cmd);
+  qs_man_print(man, "%s%s -f <format_string> -o <out_file> [-p [-v]] [-x [<num>]] [-u <name>] [-m] [-c <path>]\n", man ? "" : "Usage: ", cmd);
   printf("\n");
   if(man) {
     printf(".SH DESCRIPTION\n");
@@ -1216,6 +1296,9 @@ static void usage(const char *cmd, int man) {
   qs_man_println(man, "     U defines the user tracking id (%%{mod_qos_user_id}e)\n");
   qs_man_println(man, "     Q defines the mod_qos_ev event message (%%{mod_qos_ev}e)\n");
   qs_man_println(man, "     C defines the element for the detailed log (-c option), e.g. \"%%U\"\n");
+  qs_man_println(man, "     s arbitraty counter to add up (sum within a minute)\n");
+  qs_man_println(man, "     a arbitraty counter to build an average from (average per request)\n");
+  qs_man_println(man, "     A arbitraty counter to build an average from (average per request)\n");
   qs_man_println(man, "     . defines an element to ignore (unknown string)\n");
   if(man) printf("\n.TP\n");
   qs_man_print(man, "  -o <out_file>\n");
@@ -1236,9 +1319,10 @@ static void usage(const char *cmd, int man) {
   if(man) printf("\n");
   qs_man_print(man, "     Verbose mode.\n");
   if(man) printf("\n.TP\n");
-  qs_man_print(man, "  -x\n");
+  qs_man_print(man, "  -x [<num>]\n");
   if(man) printf("\n");
-  qs_man_print(man, "     Rotates the output file once a day (move).\n");
+  qs_man_print(man, "     Rotates the output file once a day (move). You may specify the number of\n");
+  qs_man_print(man, "     rotated files to keep. Default are %d.\n", QS_GENERATIONS);
   if(man) printf("\n.TP\n");
   qs_man_print(man, "  -u <name>\n");
   if(man) printf("\n");
@@ -1373,6 +1457,10 @@ int main(int argc, const char *const argv[]) {
           // enable average duration in ms
           m_avms = 1;
         }
+        if(strchr(config, 's') || strchr(config, 'a') || strchr(config, 'A')) {
+          // enable custom counter
+          m_customcounter = 1;
+        }
       }
     } else if(strcmp(*argv,"-o") == 0) { /* this is the out file */
       if (--argc >= 1) {
@@ -1398,6 +1486,13 @@ int main(int argc, const char *const argv[]) {
       m_verbose = 1;
     } else if(strcmp(*argv,"-x") == 0) { /* activate log rotation */
       m_rotate = 1;
+      if(argc > 1) {
+        if(*argv[1] >= '0' && *argv[1] <= '9') {
+          argc--;
+          argv++;
+          m_generations = atoi(*argv);
+        }
+      }
     } else if(strcmp(*argv,"-h") == 0) {
       usage(cmd, 0);
     } else if(strcmp(*argv,"--help") == 0) {
@@ -1447,7 +1542,7 @@ int main(int argc, const char *const argv[]) {
     if(file) {
       m_f = fopen(file, "a+");
       if(!m_f) {
-        m_f == stdout;
+        m_f = stdout;
       }
     }
     for(i = 0; i < apr_table_elts(m_client_entries)->nelts; i++) {
