@@ -23,7 +23,7 @@
  *
  */
 
-static const char revision[] = "$Id: qspng.c,v 1.13 2012/02/08 11:46:39 pbuchbinder Exp $";
+static const char revision[] = "$Id: qspng.c,v 1.15 2012/04/05 07:52:57 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <strings.h>
@@ -62,6 +62,7 @@ static const qs_png_elt_t qs_png_elts[] = {
   { "ib/s", "bytes per second (in)",     30, 45, 125 },
   { "esco", "established connections per minute", 40, 95, 140 },
   { "av", "average response time", 40, 95, 140 },
+  { "avms", "average response time in milliseconds", 45, 95, 135 },
   { "<1s", "requests faster than 1 second", 35, 95, 180 },
   { "1s", "requests faster or equal than 1 second", 35, 90, 180 },
   { "2s", "requests with 2 seconds response time", 30, 85, 180 },
@@ -598,7 +599,7 @@ static void usage(char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qslog(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qslogger(1), qslog(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://opensource.adnovum.ch/mod_qos/\n");
   } else {
